iotools.RedirectedStreams
=========================

.. abjad-lineage:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams

.. autoclass:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__enter__
      ~abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__eq__
      ~abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__exit__
      ~abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__ne__
      ~abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__repr__

Bases
-----

- :py:class:`abctools.ContextManager <abjad.tools.abctools.ContextManager.ContextManager.ContextManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__enter__
   :noindex:

.. automethod:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__eq__
   :noindex:

.. automethod:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__exit__
   :noindex:

.. automethod:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__ne__
   :noindex:

.. automethod:: abjad.tools.iotools.RedirectedStreams.RedirectedStreams.RedirectedStreams.__repr__
   :noindex:
